@@ -13,7 +13,7 @@ basics_model_fn <- function(train_data,
   if (is.null(y_col)) stop("The model formula does not contain a dependent variable.")
 
   # Check if there are random effects (Logical)
-  contains_random_effects = rand_effects(model_specifics[["model_formula"]])
+  contains_random_effects <- rand_effects(model_specifics[["model_formula"]])
 
   # Choose model_type
   if (model_specifics[["family"]] == "gaussian")
