@@ -453,8 +453,14 @@ evaluate <- function(data,
 
   # If the dataset is grouped, we need the indices and keys for the groups
   # so we can evaluate group wise
-  grouping_factor <- dplyr::group_indices(data)
+
+  # Get grouping keys
   grouping_keys <- dplyr::group_keys(data)
+  # Make sure, the grouping_keys and the dataset are in the same order
+  # As we otherwise risk adding them in the wrong order later
+  data <- dplyr::arrange(data, !!! rlang::syms(colnames(grouping_keys)))
+  # Get group indices
+  grouping_factor <- dplyr::group_indices(data)
 
   if (!is.null(models) && length(unique(grouping_factor)) != length(models)){
     stop(paste0("When the dataframe is grouped, ",
