@@ -1297,3 +1297,48 @@ test_that("evaluate() treats dfs and tbls the same",{
 #
 #
 # })
+
+test_that("evaluate() is agnostic about the order of the input data",{
+
+  dat <- data.frame("target" = c(2,1,2,1,2,1,1,1,2,2,2,1,2,1,1,2,2,2,1,1,1,1,1),
+                    "prediction" = c(0.7,0.3,0.1,0.1,0.9,0.3,0.8,0.7,0.9,0.1,0.9,0.1,
+                                   0.2,0.4,0.2,0.6,0.1,0.6,0.1,0.2,0.1,0.8,0.3),
+                    ".group" = paste0("cl_", c(1,3,2,2,3,1,3,1,2,3,2,1,2,1,1,3,3,2,1,3,2,1,1))
+                    )
+
+  eval_1 <- dat %>%
+    dplyr::group_by(.data$.group) %>%
+    evaluate(target_col = "target", prediction_cols = "prediction",type = "binomial")
+
+  eval_2 <- dat %>%
+    dplyr::arrange(.data$.group) %>%
+    dplyr::group_by(.data$.group) %>%
+    evaluate(target_col = "target", prediction_cols = "prediction",type = "binomial")
+
+  eval_3 <- dat %>%
+    dplyr::arrange(dplyr::desc(.data$.group)) %>%
+    dplyr::group_by(.data$.group) %>%
+    evaluate(target_col = "target", prediction_cols = "prediction",type = "binomial")
+
+  expect_identical(eval_1[,1:15], eval_2[,1:15])
+  expect_identical(eval_1[,1:15], eval_3[,1:15])
+
+  eval_group_1 <- dat %>%
+    dplyr::filter(.data$.group == "cl_1") %>%
+    evaluate(target_col = "target", prediction_cols = "prediction",type = "binomial")
+
+  eval_group_2 <- dat %>%
+    dplyr::filter(.data$.group == "cl_2") %>%
+    evaluate(target_col = "target", prediction_cols = "prediction",type = "binomial")
+
+  eval_group_3 <- dat %>%
+    dplyr::filter(.data$.group == "cl_3") %>%
+    evaluate(target_col = "target", prediction_cols = "prediction",type = "binomial")
+
+  eval_groups <- dplyr::bind_rows(
+    eval_group_1, eval_group_2, eval_group_3
+  )
+
+  expect_equal(eval_1[,2:15], eval_groups[,1:14])
+
+})
